pub enum IStablecoinDEXErrors {
Show 16 variants
Unauthorized(Unauthorized),
PairDoesNotExist(PairDoesNotExist),
PairAlreadyExists(PairAlreadyExists),
OrderDoesNotExist(OrderDoesNotExist),
IdenticalTokens(IdenticalTokens),
InvalidToken(InvalidToken),
TickOutOfBounds(TickOutOfBounds),
InvalidTick(InvalidTick),
InvalidFlipTick(InvalidFlipTick),
InsufficientBalance(InsufficientBalance),
InsufficientLiquidity(InsufficientLiquidity),
InsufficientOutput(InsufficientOutput),
MaxInputExceeded(MaxInputExceeded),
BelowMinimumOrderSize(BelowMinimumOrderSize),
InvalidBaseToken(InvalidBaseToken),
OrderNotStale(OrderNotStale),
}Expand description
Container for all the IStablecoinDEX custom errors.
Variants
PairDoesNotExist(PairDoesNotExist)
PairAlreadyExists(PairAlreadyExists)
OrderDoesNotExist(OrderDoesNotExist)
IdenticalTokens(IdenticalTokens)
InvalidToken(InvalidToken)
TickOutOfBounds(TickOutOfBounds)
InvalidTick(InvalidTick)
InvalidFlipTick(InvalidFlipTick)
InsufficientBalance(InsufficientBalance)
InsufficientLiquidity(InsufficientLiquidity)
InsufficientOutput(InsufficientOutput)
MaxInputExceeded(MaxInputExceeded)
BelowMinimumOrderSize(BelowMinimumOrderSize)
InvalidBaseToken(InvalidBaseToken)
OrderNotStale(OrderNotStale)
Implementations
Sourceimpl IStablecoinDEXErrors
impl IStablecoinDEXErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IStablecoinDEXErrors
impl IStablecoinDEXErrors
Creates a Unauthorized error.
error Unauthorized()Sourcepub fn pair_does_not_exist() -> Self
pub fn pair_does_not_exist() -> Self
Creates a PairDoesNotExist error.
error PairDoesNotExist()Sourcepub fn pair_already_exists() -> Self
pub fn pair_already_exists() -> Self
Creates a PairAlreadyExists error.
error PairAlreadyExists()Sourcepub fn order_does_not_exist() -> Self
pub fn order_does_not_exist() -> Self
Creates a OrderDoesNotExist error.
error OrderDoesNotExist()Sourcepub fn identical_tokens() -> Self
pub fn identical_tokens() -> Self
Creates a IdenticalTokens error.
error IdenticalTokens()Sourcepub fn invalid_token() -> Self
pub fn invalid_token() -> Self
Creates a InvalidToken error.
error InvalidToken()Sourcepub fn tick_out_of_bounds(tick: i16) -> Self
pub fn tick_out_of_bounds(tick: i16) -> Self
Creates a TickOutOfBounds error.
error TickOutOfBounds(int16)Sourcepub fn invalid_tick() -> Self
pub fn invalid_tick() -> Self
Creates a InvalidTick error.
error InvalidTick()Sourcepub fn invalid_flip_tick() -> Self
pub fn invalid_flip_tick() -> Self
Creates a InvalidFlipTick error.
error InvalidFlipTick()Sourcepub fn insufficient_balance() -> Self
pub fn insufficient_balance() -> Self
Creates a InsufficientBalance error.
error InsufficientBalance()Sourcepub fn insufficient_liquidity() -> Self
pub fn insufficient_liquidity() -> Self
Creates a InsufficientLiquidity error.
error InsufficientLiquidity()Sourcepub fn insufficient_output() -> Self
pub fn insufficient_output() -> Self
Creates a InsufficientOutput error.
error InsufficientOutput()Sourcepub fn max_input_exceeded() -> Self
pub fn max_input_exceeded() -> Self
Creates a MaxInputExceeded error.
error MaxInputExceeded()Sourcepub fn below_minimum_order_size(amount: u128) -> Self
pub fn below_minimum_order_size(amount: u128) -> Self
Creates a BelowMinimumOrderSize error.
error BelowMinimumOrderSize(uint128)Sourcepub fn invalid_base_token() -> Self
pub fn invalid_base_token() -> Self
Creates a InvalidBaseToken error.
error InvalidBaseToken()Sourcepub fn order_not_stale() -> Self
pub fn order_not_stale() -> Self
Creates a OrderNotStale error.
error OrderNotStale()Trait Implementations
Sourceimpl Clone for IStablecoinDEXErrors
impl Clone for IStablecoinDEXErrors
Sourcefn clone(&self) -> IStablecoinDEXErrors
fn clone(&self) -> IStablecoinDEXErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IStablecoinDEXErrors
impl Debug for IStablecoinDEXErrors
Sourceimpl<'de> Deserialize<'de> for IStablecoinDEXErrors
impl<'de> Deserialize<'de> for IStablecoinDEXErrors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for IStablecoinDEXErrors
Sourceimpl PartialEq for IStablecoinDEXErrors
impl PartialEq for IStablecoinDEXErrors
Sourcefn eq(&self, other: &IStablecoinDEXErrors) -> bool
fn eq(&self, other: &IStablecoinDEXErrors) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IStablecoinDEXErrors
impl Serialize for IStablecoinDEXErrors
Sourceimpl SolInterface for IStablecoinDEXErrors
impl SolInterface for IStablecoinDEXErrors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreimpl StructuralPartialEq for IStablecoinDEXErrors