pub enum IStablecoinDEXEvents {
PairCreated(PairCreated),
OrderPlaced(OrderPlaced),
OrderFilled(OrderFilled),
OrderFlipped(OrderFlipped),
FlipFailed(FlipFailed),
OrderCancelled(OrderCancelled),
}Expand description
Container for all the IStablecoinDEX events.
Variants
PairCreated(PairCreated)
OrderPlaced(OrderPlaced)
OrderFilled(OrderFilled)
OrderFlipped(OrderFlipped)
FlipFailed(FlipFailed)
OrderCancelled(OrderCancelled)
Implementations
Sourceimpl IStablecoinDEXEvents
impl IStablecoinDEXEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IStablecoinDEXEvents
impl IStablecoinDEXEvents
Sourcepub fn pair_created(key: FixedBytes<32>, base: Address, quote: Address) -> Self
pub fn pair_created(key: FixedBytes<32>, base: Address, quote: Address) -> Self
Creates a PairCreated event.
event PairCreated(bytes32,address,address)Sourcepub fn order_placed(
order_id: u128,
maker: Address,
token: Address,
amount: u128,
is_bid: bool,
tick: i16,
is_flip_order: bool,
flip_tick: i16,
) -> Self
pub fn order_placed( order_id: u128, maker: Address, token: Address, amount: u128, is_bid: bool, tick: i16, is_flip_order: bool, flip_tick: i16, ) -> Self
Creates a OrderPlaced event.
event OrderPlaced(uint128,address,address,uint128,bool,int16,bool,int16)Sourcepub fn order_filled(
order_id: u128,
maker: Address,
taker: Address,
amount_filled: u128,
partial_fill: bool,
) -> Self
pub fn order_filled( order_id: u128, maker: Address, taker: Address, amount_filled: u128, partial_fill: bool, ) -> Self
Creates a OrderFilled event.
event OrderFilled(uint128,address,address,uint128,bool)Sourcepub fn order_flipped(
order_id: u128,
maker: Address,
token: Address,
amount: u128,
is_bid: bool,
tick: i16,
flip_tick: i16,
) -> Self
pub fn order_flipped( order_id: u128, maker: Address, token: Address, amount: u128, is_bid: bool, tick: i16, flip_tick: i16, ) -> Self
Creates a OrderFlipped event.
event OrderFlipped(uint128,address,address,uint128,bool,int16,int16)Sourcepub fn flip_failed(
order_id: u128,
maker: Address,
reason: FixedBytes<4>,
) -> Self
pub fn flip_failed( order_id: u128, maker: Address, reason: FixedBytes<4>, ) -> Self
Creates a FlipFailed event.
event FlipFailed(uint128,address,bytes4)Sourcepub fn order_cancelled(order_id: u128) -> Self
pub fn order_cancelled(order_id: u128) -> Self
Creates a OrderCancelled event.
event OrderCancelled(uint128)Trait Implementations
Sourceimpl Clone for IStablecoinDEXEvents
impl Clone for IStablecoinDEXEvents
Sourcefn clone(&self) -> IStablecoinDEXEvents
fn clone(&self) -> IStablecoinDEXEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IStablecoinDEXEvents
impl Debug for IStablecoinDEXEvents
Sourceimpl<'de> Deserialize<'de> for IStablecoinDEXEvents
impl<'de> Deserialize<'de> for IStablecoinDEXEvents
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for IStablecoinDEXEvents
Sourceimpl IntoLogData for IStablecoinDEXEvents
impl IntoLogData for IStablecoinDEXEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl PartialEq for IStablecoinDEXEvents
impl PartialEq for IStablecoinDEXEvents
Sourcefn eq(&self, other: &IStablecoinDEXEvents) -> bool
fn eq(&self, other: &IStablecoinDEXEvents) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IStablecoinDEXEvents
impl Serialize for IStablecoinDEXEvents
Sourceimpl SolEventInterface for IStablecoinDEXEvents
impl SolEventInterface for IStablecoinDEXEvents
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for IStablecoinDEXEvents