IStablecoinDEXErrors

Enum IStablecoinDEXErrors 

pub enum IStablecoinDEXErrors {
Show 16 variants Unauthorized(Unauthorized), PairDoesNotExist(PairDoesNotExist), PairAlreadyExists(PairAlreadyExists), OrderDoesNotExist(OrderDoesNotExist), IdenticalTokens(IdenticalTokens), InvalidToken(InvalidToken), TickOutOfBounds(TickOutOfBounds), InvalidTick(InvalidTick), InvalidFlipTick(InvalidFlipTick), InsufficientBalance(InsufficientBalance), InsufficientLiquidity(InsufficientLiquidity), InsufficientOutput(InsufficientOutput), MaxInputExceeded(MaxInputExceeded), BelowMinimumOrderSize(BelowMinimumOrderSize), InvalidBaseToken(InvalidBaseToken), OrderNotStale(OrderNotStale),
}
Container for all the IStablecoinDEX custom errors.

Variants



Unauthorized(Unauthorized)



PairDoesNotExist(PairDoesNotExist)



PairAlreadyExists(PairAlreadyExists)



OrderDoesNotExist(OrderDoesNotExist)



IdenticalTokens(IdenticalTokens)



InvalidToken(InvalidToken)



TickOutOfBounds(TickOutOfBounds)



InvalidTick(InvalidTick)



InvalidFlipTick(InvalidFlipTick)



InsufficientBalance(InsufficientBalance)



InsufficientLiquidity(InsufficientLiquidity)



InsufficientOutput(InsufficientOutput)



MaxInputExceeded(MaxInputExceeded)



BelowMinimumOrderSize(BelowMinimumOrderSize)



InvalidBaseToken(InvalidBaseToken)



OrderNotStale(OrderNotStale)

Implementations

Source

impl IStablecoinDEXErrors

pub const SELECTORS: &'static [[u8; 4]]

All the selectors of this enum.

Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.

Prefer using SolInterface methods instead.

pub const VARIANT_NAMES: &'static [&'static str]

The names of the variants in the same order as SELECTORS.

pub const SIGNATURES: &'static [&'static str]

The signatures in the same order as SELECTORS.

pub fn signature_by_selector(selector: [u8; 4]) -> Option<&'static str>

Returns the signature for the given selector, if known.

pub fn name_by_selector(selector: [u8; 4]) -> Option<&'static str>

Returns the enum variant name for the given selector, if known.

Source

impl StablecoinDEXError

pub const fn unauthorized() -> Self

Creates an unauthorized access error.

pub const fn pair_does_not_exist() -> Self

Creates an error when pair does not exist.

pub const fn pair_already_exists() -> Self

Creates an error when pair already exists.

pub const fn order_does_not_exist() -> Self

Creates an error when order does not exist.

pub const fn identical_tokens() -> Self

Creates an error when trying to swap identical tokens.

pub const fn invalid_token() -> Self

Creates an error when a token address is not a valid TIP20 token.

pub const fn tick_out_of_bounds(tick: i16) -> Self

Creates an error for tick out of bounds.

pub const fn invalid_flip_tick() -> Self

Creates an error for invalid flip tick.

pub const fn invalid_tick() -> Self

Creates an error for invalid tick.

pub const fn insufficient_balance() -> Self

Creates an error for insufficient balance.

pub const fn insufficient_liquidity() -> Self

Creates an error for insufficient liquidity.

pub const fn insufficient_output() -> Self

Creates an error for insufficient output.

pub const fn max_input_exceeded() -> Self

Creates an error for max input exceeded.

pub const fn below_minimum_order_size(amount: u128) -> Self

Creates an error for order amount below minimum.

pub const fn invalid_base_token() -> Self

Creates an error for invalid base token.

pub const fn order_not_stale() -> Self

Creates an error when order is not stale