pub enum IStablecoinDEXErrors {
Show 16 variants
Unauthorized(Unauthorized),
PairDoesNotExist(PairDoesNotExist),
PairAlreadyExists(PairAlreadyExists),
OrderDoesNotExist(OrderDoesNotExist),
IdenticalTokens(IdenticalTokens),
InvalidToken(InvalidToken),
TickOutOfBounds(TickOutOfBounds),
InvalidTick(InvalidTick),
InvalidFlipTick(InvalidFlipTick),
InsufficientBalance(InsufficientBalance),
InsufficientLiquidity(InsufficientLiquidity),
InsufficientOutput(InsufficientOutput),
MaxInputExceeded(MaxInputExceeded),
BelowMinimumOrderSize(BelowMinimumOrderSize),
InvalidBaseToken(InvalidBaseToken),
OrderNotStale(OrderNotStale),
}Expand description
Container for all the IStablecoinDEX custom errors.
Variants
PairDoesNotExist(PairDoesNotExist)
PairAlreadyExists(PairAlreadyExists)
OrderDoesNotExist(OrderDoesNotExist)
IdenticalTokens(IdenticalTokens)
InvalidToken(InvalidToken)
TickOutOfBounds(TickOutOfBounds)
InvalidTick(InvalidTick)
InvalidFlipTick(InvalidFlipTick)
InsufficientBalance(InsufficientBalance)
InsufficientLiquidity(InsufficientLiquidity)
InsufficientOutput(InsufficientOutput)
MaxInputExceeded(MaxInputExceeded)
BelowMinimumOrderSize(BelowMinimumOrderSize)
InvalidBaseToken(InvalidBaseToken)
OrderNotStale(OrderNotStale)
Implementations
Sourceimpl IStablecoinDEXErrors
impl IStablecoinDEXErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl StablecoinDEXError
impl StablecoinDEXError
Creates an unauthorized access error.
Sourcepub const fn pair_does_not_exist() -> Self
pub const fn pair_does_not_exist() -> Self
Creates an error when pair does not exist.
Sourcepub const fn pair_already_exists() -> Self
pub const fn pair_already_exists() -> Self
Creates an error when pair already exists.
Sourcepub const fn order_does_not_exist() -> Self
pub const fn order_does_not_exist() -> Self
Creates an error when order does not exist.
Sourcepub const fn identical_tokens() -> Self
pub const fn identical_tokens() -> Self
Creates an error when trying to swap identical tokens.
Sourcepub const fn invalid_token() -> Self
pub const fn invalid_token() -> Self
Creates an error when a token address is not a valid TIP20 token.
Sourcepub const fn tick_out_of_bounds(tick: i16) -> Self
pub const fn tick_out_of_bounds(tick: i16) -> Self
Creates an error for tick out of bounds.
Sourcepub const fn invalid_flip_tick() -> Self
pub const fn invalid_flip_tick() -> Self
Creates an error for invalid flip tick.
Sourcepub const fn invalid_tick() -> Self
pub const fn invalid_tick() -> Self
Creates an error for invalid tick.
Sourcepub const fn insufficient_balance() -> Self
pub const fn insufficient_balance() -> Self
Creates an error for insufficient balance.
Sourcepub const fn insufficient_liquidity() -> Self
pub const fn insufficient_liquidity() -> Self
Creates an error for insufficient liquidity.
Sourcepub const fn insufficient_output() -> Self
pub const fn insufficient_output() -> Self
Creates an error for insufficient output.
Sourcepub const fn max_input_exceeded() -> Self
pub const fn max_input_exceeded() -> Self
Creates an error for max input exceeded.
Sourcepub const fn below_minimum_order_size(amount: u128) -> Self
pub const fn below_minimum_order_size(amount: u128) -> Self
Creates an error for order amount below minimum.
Sourcepub const fn invalid_base_token() -> Self
pub const fn invalid_base_token() -> Self
Creates an error for invalid base token.
Sourcepub const fn order_not_stale() -> Self
pub const fn order_not_stale() -> Self
Creates an error when order is not stale